RuntimeBlob

Struct RuntimeBlob 

pub struct RuntimeBlob(/* private fields */);
A program blob containing a Substrate runtime.

Implementations

Source

impl RuntimeBlob

pub fn uncompress_if_needed(wasm_code: &[u8]) -> Result<Self, WasmError>

Create RuntimeBlob from the given WASM or PolkaVM compressed program blob.

See sp_maybe_compressed_blob for details about decompression.

pub fn new(raw_blob: &[u8]) -> Result<Self, WasmError>

Create RuntimeBlob from the given WASM or PolkaVM program blob.

Returns Err if the blob cannot be deserialized.

Will only accept a PolkaVM program if the SUBSTRATE_ENABLE_POLKAVM environment variable is set to 1.

pub fn inject_stack_depth_metering( self, stack_depth_limit: u32, ) -> Result<Self, WasmError>

Run a pass that instrument this module so as to introduce a deterministic stack height limit.

It will introduce a global mutable counter. The instrumentation will increase the counter according to the “cost” of the callee. If the cost exceeds the stack_depth_limit constant, the instrumentation will trap. The counter will be decreased as soon as the the callee returns.

The stack cost of a function is computed based on how much locals there are and the maximum depth of the wasm operand stack.

Only valid for WASM programs; will return an error if the blob is a PolkaVM program.

pub fn convert_memory_import_into_export(&mut self) -> Result<(), WasmError>

Converts a WASM memory import into a memory section and exports it.

Does nothing if there’s no memory import.

May return an error in case the WASM module is invalid.

Only valid for WASM programs; will return an error if the blob is a PolkaVM program.

pub fn setup_memory_according_to_heap_alloc_strategy( &mut self, heap_alloc_strategy: HeapAllocStrategy, ) -> Result<(), WasmError>

Modifies the blob’s memory section according to the given heap_alloc_strategy.

Will return an error in case there is no memory section present, or if the memory section is empty.

Only valid for WASM programs; will return an error if the blob is a PolkaVM program.

pub fn custom_section_contents(&self, section_name: &str) -> Option<&[u8]>

Scans the wasm blob for the first section with the name that matches the given. Returns the contents of the custom section if found or None otherwise.

Only valid for WASM programs; will return an error if the blob is a PolkaVM program.

pub fn serialize(self) -> Vec<u8>

Consumes this runtime blob and serializes it.

pub fn as_polkavm_blob(&self) -> Option<&ProgramBlob<'_>>

Gets a reference to the inner PolkaVM program blob, if this is a PolkaVM program.