pub enum HeapAllocStrategy {
Static {
extra_pages: u32,
},
Dynamic {
maximum_pages: Option<u32>,
},
}Expand description
Defines the heap pages allocation strategy the wasm runtime should use.
A heap page is defined as 64KiB of memory.
Variants
Static
Allocate a static number of heap pages.
The total number of allocated heap pages is the initial number of heap pages requested by
the wasm file plus the extra_pages.
Fields
Dynamic
Allocate the initial heap pages as requested by the wasm file and then allow it to grow dynamically.